## About

__virtualenv-tauthon__ is an external [Virtualenv](https://github.com/pypa/virtualenv) plugin that adds
[Tauthon](https://github.com/naftaliharris/tauthon) support,
as described [here](https://virtualenv.pypa.io/en/latest/extend.html#creators).

With this module and Tauthon installed, you can create a Tauthon-based virtual environment like this:

```shell
virtualenv -p tauthon2.8 my_venv
```

## Installation

This package is available on PyPi: 

```shell
pip install virtualenv-tauthon
```

## License

MIT

## Credits

- author: Ștefan Talpalaru <stefantalpalaru@yahoo.com>

- homepage: https://github.com/stefantalpalaru/virtualenv-tauthon
